==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/el.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Σχόλια",
    "Unknown user" : "Άγνωστος χρήστης",
    "New comment …" : "Νέο σχόλιο ...",
    "Delete comment" : "Διαγραφή σχολίου",
    "Post" : "Δημοσίευση",
    "Cancel" : "Ακύρωση",
    "Edit comment" : "Επεξεργασία σχολίου",
    "[Deleted user]" : "[Διαγραμμένος χρήστης]",
    "No comments yet, start the conversation!" : "Δεν υπάρχουν σχόλια, ξεκινήστε την συζήτηση!",
    "More comments …" : "Περισσότερα σχόλια ...",
    "Save" : "Αποθήκευση",
    "Allowed characters {count} of {max}" : "Επιτρεπόμενοι χαρακτήρες {count} από {max}",
    "Error occurred while retrieving comment with id {id}" : "Ένα σφάλμα προέκυψε κατά την λήψη σχολίου με αναγνωριστικό {id}",
    "Error occurred while updating comment with id {id}" : "Ένα σφάλμα προέκυψε κατά την ενημέρωση του σχολίου με το αναγνωριστικό {id}",
    "Error occurred while posting comment" : "Ένα σφάλμα προέκυψε κατά την δημοσίευση σχολίου",
    "_%n unread comment_::_%n unread comments_" : ["%n αδιάβαστο σχόλιο","%n αδιάβαστα σχόλια"],
    "Comment" : "Σχόλιο",
    "You commented" : "Σχολιάσατε",
    "%1$s commented" : "%1$s σχολίασε",
    "{author} commented" : "Ο {author} σχολίασε",
    "You commented on %1$s" : "Σχολιάσατε στο %1$s",
    "You commented on {file}" : "Σχολιάσατε στο {file}",
    "%1$s commented on %2$s" : "%1$s σχολίασε στο %2$s",
    "{author} commented on {file}" : "Ο {author} σχολίασε στο {file}",
    "<strong>Comments</strong> for files" : "<strong>Σχόλια</strong> για αρχεία",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Ο (πρόσφατα) διεγραμμένος χρήστης σας ανέφερε σε σχόλιο στο “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Ο (πρόσφατα) διεγραμμένος χρήστης σας ανέφερε σε σχόλιο στο “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s σας ανέφερε σε σχόλιο στο “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "Ο {user} σας ανέφερε σε σχόλιο στο “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/el.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Σχόλια",
    "Unknown user" : "Άγνωστος χρήστης",
    "New comment …" : "Νέο σχόλιο ...",
    "Delete comment" : "Διαγραφή σχολίου",
    "Post" : "Δημοσίευση",
    "Cancel" : "Ακύρωση",
    "Edit comment" : "Επεξεργασία σχολίου",
    "[Deleted user]" : "[Διαγραμμένος χρήστης]",
    "No comments yet, start the conversation!" : "Δεν υπάρχουν σχόλια, ξεκινήστε την συζήτηση!",
    "More comments …" : "Περισσότερα σχόλια ...",
    "Save" : "Αποθήκευση",
    "Allowed characters {count} of {max}" : "Επιτρεπόμενοι χαρακτήρες {count} από {max}",
    "Error occurred while retrieving comment with id {id}" : "Ένα σφάλμα προέκυψε κατά την λήψη σχολίου με αναγνωριστικό {id}",
    "Error occurred while updating comment with id {id}" : "Ένα σφάλμα προέκυψε κατά την ενημέρωση του σχολίου με το αναγνωριστικό {id}",
    "Error occurred while posting comment" : "Ένα σφάλμα προέκυψε κατά την δημοσίευση σχολίου",
    "_%n unread comment_::_%n unread comments_" : ["%n αδιάβαστο σχόλιο","%n αδιάβαστα σχόλια"],
    "Comment" : "Σχόλιο",
    "You commented" : "Σχολιάσατε",
    "%1$s commented" : "%1$s σχολίασε",
    "{author} commented" : "Ο {author} σχολίασε",
    "You commented on %1$s" : "Σχολιάσατε στο %1$s",
    "You commented on {file}" : "Σχολιάσατε στο {file}",
    "%1$s commented on %2$s" : "%1$s σχολίασε στο %2$s",
    "{author} commented on {file}" : "Ο {author} σχολίασε στο {file}",
    "<strong>Comments</strong> for files" : "<strong>Σχόλια</strong> για αρχεία",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s σας ανέφερε σε σχόλιο στο “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "Ο {user} σας ανέφερε σε σχόλιο στο “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Ο (πρόσφατα) διεγραμμένος χρήστης σας ανέφερε σε σχόλιο στο “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Ο (πρόσφατα) διεγραμμένος χρήστης σας ανέφερε σε σχόλιο στο “{file}”"
},
"nplurals=2; plural=(n != 1);");
